@@ -333,6 +333,7 @@ pub enum MarketInstruction {
     /// 9. `[]` the rent sysvar
     /// 10. `[]` open orders market authority (optional)
     /// 11. `[]` prune authority (optional, requires open orders market authority)
+    /// 12. `[]` crank authority (optional, requires prune authority)
     InitializeMarket(InitializeMarketInstruction),
     /// 0. `[writable]` the market
     /// 1. `[writable]` the OpenOrders account to use
@@ -343,21 +344,19 @@ pub enum MarketInstruction {
     /// 6. `[writable]` pc vault
     /// 7. `[]` spl token program
     /// 8. `[]` the rent sysvar
-    /// 9. `[writable]` (optional) the (M)SRM account used for fee discounts
+    /// 9. `[]` (optional) the (M)SRM account used for fee discounts
     NewOrder(NewOrderInstructionV1),
     /// 0. `[writable]` market
     /// 1. `[writable]` req_q
     /// 2. `[writable]` event_q
     /// 3. `[writable]` bids
     /// 4. `[writable]` asks
-    /// 5. `[writable]` coin fee receivable account
-    /// 6. `[writable]` pc fee receivable account
     MatchOrders(u16),
     /// ... `[writable]` OpenOrders
     /// accounts.len() - 4 `[writable]` market
     /// accounts.len() - 3 `[writable]` event queue
-    /// accounts.len() - 2 `[writable]` coin fee receivable account
-    /// accounts.len() - 1 `[writable]` pc fee receivable account
+    /// accounts.len() - 2 `[]`
+    /// accounts.len() - 1 `[]`
     ConsumeEvents(u16),
     /// 0. `[]` market
     /// 1. `[writable]` OpenOrders
@@ -399,7 +398,7 @@ pub enum MarketInstruction {
     /// 6. `[writable]` pc vault
     /// 7. `[]` spl token program
     /// 8. `[]` the rent sysvar
-    /// 9. `[writable]` (optional) the (M)SRM account used for fee discounts
+    /// 9. `[]` (optional) the (M)SRM account used for fee discounts
     NewOrderV2(NewOrderInstructionV2),
     /// 0. `[writable]` the market
     /// 1. `[writable]` the OpenOrders account to use
@@ -413,7 +412,7 @@ pub enum MarketInstruction {
     /// 9. `[writable]` pc vault
     /// 10. `[]` spl token program
     /// 11. `[]` the rent sysvar
-    /// 12. `[writable]` (optional) the (M)SRM account used for fee discounts
+    /// 12. `[]` (optional) the (M)SRM account used for fee discounts
     NewOrderV3(NewOrderInstructionV3),
     /// 0. `[writable]` market
     /// 1. `[writable]` bids
@@ -430,10 +429,17 @@ pub enum MarketInstruction {
     /// 5. `[writable]` event_q
     CancelOrderByClientIdV2(u64),
     /// 0. `[writable]` market
-    /// 1. `[writable]` bids
-    /// 2. `[writable]` asks
-    /// 3. `[writable]` OpenOrders
-    /// 4. `[]`
+    /// 1. `[writable]` the request queue
+    /// 2. `[writable]` the event queue
+    /// 3. `[writable]` bids
+    /// 4. `[writable]` asks
+    /// 5. `[writable]` the coin currency wallet account
+    /// 6. `[writable]` the price currency wallet account
+    /// 7. `[]` signer
+    /// 8. `[writable]` coin vault
+    /// 9. `[writable]` pc vault
+    /// 10. `[]` spl token program
+    /// 11. `[]` (optional) the (M)SRM account used for fee discounts
     SendTake(SendTakeInstruction),
     /// 0. `[writable]` OpenOrders
     /// 1. `[signer]` the OpenOrders owner
@@ -443,7 +449,7 @@ pub enum MarketInstruction {
     /// 0. `[writable]` OpenOrders
     /// 1. `[signer]` the OpenOrders owner
     /// 2. `[]` market
-    /// 3. `[]` the rent sysvar
+    /// 3. `[]`
     /// 4. `[signer]` open orders market authority (optional).
     InitOpenOrders,
     /// Removes all orders for a given open orders account from the orderbook.
@@ -456,6 +462,11 @@ pub enum MarketInstruction {
     /// 5. `[]` open orders owner.
     /// 6. `[writable]` event queue.
     Prune(u16),
+    /// ... `[writable]` OpenOrders
+    /// accounts.len() - 3 `[writable]` market
+    /// accounts.len() - 2 `[writable]` event queue
+    /// accounts.len() - 1 `[signer]` crank authority
+    ConsumeEventsPermissioned(u16),
 }
 
 impl MarketInstruction {
@@ -553,6 +564,10 @@ impl MarketInstruction {
                 let limit = array_ref![data, 0, 2];
                 MarketInstruction::Prune(u16::from_le_bytes(*limit))
             }
+            (17, 2) => {
+                let limit = array_ref![data, 0, 2];
+                MarketInstruction::ConsumeEventsPermissioned(u16::from_le_bytes(*limit))
+            }
             _ => return None,
         })
     }
@@ -577,6 +592,7 @@ pub fn initialize_market(
     pc_vault_pk: &Pubkey,
     authority_pk: Option<&Pubkey>,
     prune_authority_pk: Option<&Pubkey>,
+    consume_events_authority_pk: Option<&Pubkey>,
     // srm_vault_pk: &Pubkey,
     bids_pk: &Pubkey,
     asks_pk: &Pubkey,
@@ -631,6 +647,10 @@ pub fn initialize_market(
         if let Some(prune_auth) = prune_authority_pk {
             let authority = AccountMeta::new_readonly(*prune_auth, false);
             accounts.push(authority);
+            if let Some(consume_events_auth) = consume_events_authority_pk {
+                let authority = AccountMeta::new_readonly(*consume_events_auth, false);
+                accounts.push(authority);
+            }
         }
     }
 
@@ -691,7 +711,7 @@ pub fn new_order(
         AccountMeta::new_readonly(*rent_sysvar_id, false),
     ];
     if let Some(key) = srm_account_referral {
-        accounts.push(AccountMeta::new(*key, false))
+        accounts.push(AccountMeta::new_readonly(*key, false))
     }
     Ok(Instruction {
         program_id: *program_id,
@@ -755,6 +775,31 @@ pub fn consume_events(
     })
 }
 
+pub fn consume_events_permissioned(
+    program_id: &Pubkey,
+    open_orders_accounts: Vec<&Pubkey>,
+    market: &Pubkey,
+    event_queue: &Pubkey,
+    consume_events_authority: &Pubkey,
+    limit: u16,
+) -> Result<Instruction, DexError> {
+    let data = MarketInstruction::ConsumeEventsPermissioned(limit).pack();
+    let mut accounts: Vec<AccountMeta> = open_orders_accounts
+        .iter()
+        .map(|key| AccountMeta::new(**key, false))
+        .collect();
+    accounts.append(&mut vec![
+        AccountMeta::new(*market, false),
+        AccountMeta::new(*event_queue, false),
+        AccountMeta::new_readonly(*consume_events_authority, true),
+    ]);
+    Ok(Instruction {
+        program_id: *program_id,
+        data,
+        accounts,
+    })
+}
+
 pub fn cancel_order(
     program_id: &Pubkey,
     market: &Pubkey,
@@ -947,7 +992,7 @@ pub fn prune(
         AccountMeta::new(*bids, false),
         AccountMeta::new(*asks, false),
         AccountMeta::new_readonly(*prune_authority, true),
-        AccountMeta::new_readonly(*open_orders, false),
+        AccountMeta::new(*open_orders, false),
         AccountMeta::new_readonly(*open_orders_owner, false),
         AccountMeta::new(*event_q, false),
     ];
