@@ -1,4 +1,4 @@
-#![deny(safe_packed_borrows)]
+#![deny(unaligned_references)]
 #![allow(clippy::try_err)]
 
 #[macro_use]
